# coding: utf-8

"""
    GraphQL support

    GraphQL endpoint to query Knowledge Graphs

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class AddOnConfiguration(BaseModel):
    """
    An Add-On configuration
    """ # noqa: E501
    can_do_content_expansion: Optional[StrictBool] = Field(default=None, description="Whether this Add-on can do content expansion")
    can_import_to_wordpress: Optional[StrictBool] = Field(default=None, description="Whether this Add-on can import to WordPress.")
    key: Optional[StrictStr] = Field(default=None, description="A key")
    wp_admin: Optional[StrictStr] = Field(default=None, description="The wp-admin endpoint for a website using the key.")
    wp_json: Optional[StrictStr] = Field(default=None, description="The wp-json endpoint for a website using the key.")
    __properties: ClassVar[List[str]] = ["can_do_content_expansion", "can_import_to_wordpress", "key", "wp_admin", "wp_json"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AddOnConfiguration from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "can_do_content_expansion",
            "can_import_to_wordpress",
            "key",
            "wp_admin",
            "wp_json",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AddOnConfiguration from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "can_do_content_expansion": obj.get("can_do_content_expansion"),
            "can_import_to_wordpress": obj.get("can_import_to_wordpress"),
            "key": obj.get("key"),
            "wp_admin": obj.get("wp_admin"),
            "wp_json": obj.get("wp_json")
        })
        return _obj


